@@ -20,12 +20,17 @@ from cprocsp import csp, cryptoapi
 
 from . import KeysetException
 
+enc = sys.getdefaultencoding()
+
 if sys.version_info >= (3,):
     ord = lambda x: x
-    _decode = lambda x: str(x, sys.getdefaultencoding())
+    if enc == 'ascii':
+        _decode = cryptoapi._to_hex
+    else:
+        _decode = lambda x: str(x, enc)
     unicode = str
 else:
-    _decode = unicode
+    _decode = unicode if enc != 'ascii' else cryptoapi._to_hex
 
 
 def _rarsplit(fn):
@@ -174,10 +179,10 @@ class hdimage(object):
                     try:
                         keyspec = getattr(csp, keyname)
                         key = self.ctx.get_key(keyspec)
-                    except ValueError:
+                        cert = key.extract_cert()
+                        zf.writestr('{0}.cer'.format(keyname), cert)
+                    except:
                         continue
-                    cert = key.extract_cert()
-                    zf.writestr('{0}.cer'.format(keyname), cert)
                 zf.close()
         return filename
 
